/* PRO-SCAMS "@@(#) settings_popup.c, Rev: 1.3.0.0" */

/* -----                                                                */
/*                                                                      */
/* UWDIALER Version 1.0                                        12/05/93 */
/*                                                                      */
/* AUTHOR: William C. Brown                                             */
/* VERSION: 1.0 (beta)                                                  */
/* DESCRIPTION: To provide a nice X based dialer interface that works   */
/*              in conjunction with the connection server in SVR4.2.    */
/*                                                                      */
/* -------------------------------------------------------------------- */
/* Notes:                                                               */
/*                                                                      */
/*                                                                ----- */

#include <stdio.h>
#include <termios.h>
#include <dial.h>
#include <errno.h>

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Shell.h>
#include <Xol/OpenLook.h>
#include <Xol/RubberTile.h>
#include <Xol/Form.h>
#include <Xol/FButtons.h>
#include <Xol/Caption.h>
#include <Xol/TextField.h>
#include <Xol/StaticText.h>
#include <Xol/ScrollingL.h>

#include "uwdialer.h"

static String   Speed_Fields[] = {XtNlabel, XtNselectProc, XtNclientData};
static XtArgVal Speed_Items[] =
	 {(XtArgVal)"300",   (XtArgVal)Set_Speed, (XtArgVal)300,
          (XtArgVal)"1200",  (XtArgVal)Set_Speed, (XtArgVal)1200,
          (XtArgVal)"2400",  (XtArgVal)Set_Speed, (XtArgVal)2400,
          (XtArgVal)"4800",  (XtArgVal)Set_Speed, (XtArgVal)4800,
          (XtArgVal)"9600",  (XtArgVal)Set_Speed, (XtArgVal)9600,
          (XtArgVal)"19200", (XtArgVal)Set_Speed, (XtArgVal)19200,
          (XtArgVal)"38400", (XtArgVal)Set_Speed, (XtArgVal)38400};


static String   Size_Fields[] = {XtNlabel, XtNselectProc, XtNclientData};
static XtArgVal Size_Items[] =
	 {(XtArgVal)"CS6",  (XtArgVal)Set_Size, (XtArgVal)6,
          (XtArgVal)"CS7",  (XtArgVal)Set_Size, (XtArgVal)7,
          (XtArgVal)"CS8",  (XtArgVal)Set_Size, (XtArgVal)8};

static String   Parity_Fields[] = {XtNlabel, XtNselectProc, XtNclientData};
static XtArgVal Parity_Items[] =
	 {(XtArgVal)"EVEN",  (XtArgVal)Set_Parity, (XtArgVal)"EVEN",
          (XtArgVal)"ODD",   (XtArgVal)Set_Parity, (XtArgVal)"ODD",
          (XtArgVal)"NONE",  (XtArgVal)Set_Parity, (XtArgVal)"NONE"};

static String   Flow_Fields[] = {XtNlabel, XtNselectProc, XtNclientData};
static XtArgVal Flow_Items[] =
	 {(XtArgVal)"ON",  (XtArgVal)Set_Flow, (XtArgVal)"ON",
          (XtArgVal)"OFF", (XtArgVal)Set_Flow, (XtArgVal)"OFF"};

static String   Dis_Fields[] = {XtNlabel, XtNselectProc};
static XtArgVal Dis_Items[] = {(XtArgVal)"Dismiss",  (XtArgVal)Call_Dismiss};

static String   Dial_Fields[] = {XtNlabel, XtNselectProc};
static XtArgVal Dial_Items[] = {(XtArgVal)"Dial",  (XtArgVal)Call_Dial};

static String   Save_Fields[] = {XtNlabel, XtNselectProc};
static XtArgVal Save_Items[] = {(XtArgVal)"Save",  (XtArgVal)Call_Save};

#define	NUM_SPEED	7
#define	NUM_SIZE	3
#define	NUM_PAR		3
#define	NUM_FLOW	2

Widget Te1, Te2, SettingsTop,
       Speed, Parity, Size, Flow;

void Settings(int Indicator)
{
	Arg args[20];
	int AC;
	Widget Rub1,
	       Cap1,
	       Cap2,
	       Cap3,
	       Cap4,
	       Cap5,
	       Cap6,
	       Go,
	       Bu1,
	       Bu2,
	       Invis,
	       Form;
	extern Widget TopLevel;

	void _Jump();

	AC = 0;
	if(Indicator == MANUAL) {
        	XtSetArg(args[AC], XtNtitle, "Settings Popup");   AC++;
	}
	else {
        	XtSetArg(args[AC], XtNtitle, "Add System Popup"); AC++;
	}
        XtSetArg(args[AC], XtNresizeCorners, FALSE);              AC++;
	SettingsTop = XtAppCreateShell("uwdialer", "UWdialer", 
			applicationShellWidgetClass, XtDisplay(TopLevel),
			args, AC);

	AC = 0;
        XtSetArg(args[AC], XtNshadowThickness, 2);             AC++;
        XtSetArg(args[AC], XtNshadowType, OL_SHADOW_OUT);      AC++;
        XtSetArg(args[AC], XtNpaneGravity, NorthSouthGravity); AC++;
        Rub1 = XtCreateManagedWidget ("rubber", rubberTileWidgetClass,
                                        SettingsTop, args, AC);

	AC = 0;
        Form = XtCreateManagedWidget ("form", formWidgetClass,
                                        Rub1, NULL, 0);

	AC = 0;
	XtSetArg(args[AC], XtNlabel, "Baud rate:"); AC++;
	XtSetArg(args[AC], XtNyRefName, "form");    AC++;
	XtSetArg(args[AC], XtNyOffset, 15);	    AC++;
	XtSetArg(args[AC], XtNxOffset, 15);	    AC++;
	XtSetArg(args[AC], XtNxAttachRight, TRUE);  AC++;
	XtSetArg(args[AC], XtNxVaryOffset, TRUE);   AC++;
	XtSetArg(args[AC], XtNxAttachOffset, 15);   AC++;
        Cap1 = XtCreateManagedWidget ("cap1", captionWidgetClass,
                                        Form, args, AC);

	AC = 0;
        XtSetArg(args[AC], XtNexclusives, True);                      AC++;
        XtSetArg(args[AC], XtNbuttonType, OL_RECT_BTN);               AC++;
        XtSetArg(args[AC], XtNitemFields, Speed_Fields);              AC++;
        XtSetArg(args[AC], XtNnumItemFields, XtNumber(Speed_Fields)); AC++;
        XtSetArg(args[AC], XtNitems, Speed_Items);                    AC++;
        XtSetArg(args[AC], XtNlayoutType, OL_FIXEDROWS);              AC++;
        XtSetArg(args[AC], XtNmeasure, 1);                            AC++;
        XtSetArg(args[AC], XtNnumItems, NUM_SPEED);                   AC++;
	XtSetArg(args[AC], XtNnoneSet, TRUE);			      AC++;
        Speed = XtCreateManagedWidget ("excl", flatButtonsWidgetClass,
                                     Cap1, args, AC);

	AC = 0;
	XtSetArg(args[AC], XtNlabel, "Character size:"); AC++;
	XtSetArg(args[AC], XtNyRefName, "cap1");         AC++;
	XtSetArg(args[AC], XtNyOffset, 15);	         AC++;
	XtSetArg(args[AC], XtNyAddHeight, TRUE);         AC++;
	XtSetArg(args[AC], XtNxOffset, 15);	         AC++;
        Cap2 = XtCreateManagedWidget ("cap2", captionWidgetClass,
                                        Form, args, AC);

	AC = 0;
        XtSetArg(args[AC], XtNexclusives, True);                     AC++;
        XtSetArg(args[AC], XtNbuttonType, OL_RECT_BTN);              AC++;
        XtSetArg(args[AC], XtNitemFields, Size_Fields);              AC++;
        XtSetArg(args[AC], XtNnumItemFields, XtNumber(Size_Fields)); AC++;
        XtSetArg(args[AC], XtNitems, Size_Items);                    AC++;
        XtSetArg(args[AC], XtNlayoutType, OL_FIXEDROWS);             AC++;
        XtSetArg(args[AC], XtNmeasure, 1);                           AC++;
        XtSetArg(args[AC], XtNnumItems, NUM_SIZE);                   AC++;
	XtSetArg(args[AC], XtNnoneSet, TRUE);			     AC++;
        Size = XtCreateManagedWidget ("excl", flatButtonsWidgetClass,
                                     Cap2, args, AC);

	AC = 0;
	XtSetArg(args[AC], XtNlabel, "Parity bits:");    AC++;
	XtSetArg(args[AC], XtNyRefName, "cap2");         AC++;
	XtSetArg(args[AC], XtNyOffset, 15);	         AC++;
	XtSetArg(args[AC], XtNyAddHeight, TRUE);         AC++;
	XtSetArg(args[AC], XtNxOffset, 15);	         AC++;
        Cap3 = XtCreateManagedWidget ("cap3", captionWidgetClass,
                                        Form, args, AC);

	AC = 0;
        XtSetArg(args[AC], XtNexclusives, True);                       AC++;
        XtSetArg(args[AC], XtNbuttonType, OL_RECT_BTN);                AC++;
        XtSetArg(args[AC], XtNitemFields, Parity_Fields);              AC++;
        XtSetArg(args[AC], XtNnumItemFields, XtNumber(Parity_Fields)); AC++;
        XtSetArg(args[AC], XtNitems, Parity_Items);                    AC++;
        XtSetArg(args[AC], XtNlayoutType, OL_FIXEDROWS);               AC++;
        XtSetArg(args[AC], XtNmeasure, 1);                             AC++;
        XtSetArg(args[AC], XtNnumItems, NUM_PAR);                      AC++;
	XtSetArg(args[AC], XtNnoneSet, TRUE);			       AC++;
        Parity = XtCreateManagedWidget ("excl", flatButtonsWidgetClass,
                                     Cap3, args, AC);

	AC = 0;
	XtSetArg(args[AC], XtNlabel, "Flow Control:");   AC++;
	XtSetArg(args[AC], XtNyRefName, "cap3");         AC++;
	XtSetArg(args[AC], XtNyOffset, 15);	         AC++;
	XtSetArg(args[AC], XtNyAddHeight, TRUE);         AC++;
	XtSetArg(args[AC], XtNxOffset, 15);	         AC++;
        Cap4 = XtCreateManagedWidget ("cap4", captionWidgetClass,
                                        Form, args, AC);

	AC = 0;
        XtSetArg(args[AC], XtNexclusives, True);                     AC++;
        XtSetArg(args[AC], XtNbuttonType, OL_RECT_BTN);              AC++;
        XtSetArg(args[AC], XtNitemFields, Flow_Fields);              AC++;
        XtSetArg(args[AC], XtNnumItemFields, XtNumber(Flow_Fields)); AC++;
        XtSetArg(args[AC], XtNitems, Flow_Items);                    AC++;
        XtSetArg(args[AC], XtNlayoutType, OL_FIXEDROWS);             AC++;
        XtSetArg(args[AC], XtNmeasure, 1);                           AC++;
        XtSetArg(args[AC], XtNnumItems, NUM_FLOW);                   AC++;
	XtSetArg(args[AC], XtNnoneSet, TRUE);			     AC++;
        Flow = XtCreateManagedWidget ("excl", flatButtonsWidgetClass,
                                     Cap4, args, AC);

	if(Indicator == MANUAL) {
		AC = 0;
		XtSetArg(args[AC], XtNlabel, "Tty line:");  AC++;
		XtSetArg(args[AC], XtNyRefName, "cap4");    AC++;
		XtSetArg(args[AC], XtNyOffset, 25);	    AC++;
		XtSetArg(args[AC], XtNyAddHeight, TRUE);    AC++;
		XtSetArg(args[AC], XtNxOffset, 15);	    AC++;
		Cap5 = XtCreateManagedWidget ("cap5", captionWidgetClass,
						Form, args, AC);
	}
	else {
		AC = 0;
		XtSetArg(args[AC], XtNlabel, "System Name:");  AC++;
		XtSetArg(args[AC], XtNyRefName, "cap4");       AC++;
		XtSetArg(args[AC], XtNyOffset, 25);	       AC++;
		XtSetArg(args[AC], XtNyAddHeight, TRUE);       AC++;
		XtSetArg(args[AC], XtNxOffset, 15);	       AC++;
		Cap5 = XtCreateManagedWidget ("cap5", captionWidgetClass,
						Form, args,    AC);
	}

	AC = 0;
	XtSetArg(args[AC], XtNmaximumSize, 15);    AC++;
	XtSetArg(args[AC], XtNcharsVisible, 15);   AC++;
	Te1 = XtCreateManagedWidget ("te", textFieldWidgetClass,
					Cap5, args, AC);

	AC = 0;
	XtSetArg(args[AC], XtNlabel, "Phone Number:");       AC++;
	XtSetArg(args[AC], XtNyRefName, "cap5");             AC++;
	XtSetArg(args[AC], XtNyOffset, 15);	             AC++;
	XtSetArg(args[AC], XtNyAddHeight, TRUE);             AC++;
	XtSetArg(args[AC], XtNxOffset, 15);	             AC++;
	Cap6 = XtCreateManagedWidget ("cap6", captionWidgetClass,
					Form, args, AC);

	AC = 0;
	XtSetArg(args[AC], XtNmaximumSize, 15);    AC++;
	XtSetArg(args[AC], XtNcharsVisible, 15);   AC++;
	Te2 = XtCreateManagedWidget ("te", textFieldWidgetClass,
					Cap6, args, AC);

	XtAddCallback (Te1, XtNverification, _Jump, Te2);
	XtAddCallback (Te2, XtNverification, _Jump, Te1);

	if(Indicator == MANUAL) {
		AC = 0;
		XtSetArg(args[AC], XtNbuttonType, OL_OBLONG_BTN);  AC++;
		XtSetArg(args[AC], XtNitemFields, Dial_Fields);    AC++;
		XtSetArg(args[AC], XtNnumItemFields, 2);           AC++;
		XtSetArg(args[AC], XtNitems, Dial_Items);          AC++;
		XtSetArg(args[AC], XtNlayoutType, OL_FIXEDROWS);   AC++;
		XtSetArg(args[AC], XtNmeasure, 1);                 AC++;
		XtSetArg(args[AC], XtNnumItems, 1);                AC++;
		XtSetArg(args[AC], XtNyRefName, "cap6");           AC++;
		XtSetArg(args[AC], XtNyOffset, 25);	           AC++;
		XtSetArg(args[AC], XtNyAddHeight, TRUE);	   AC++;
		XtSetArg(args[AC], XtNxOffset, 50);      	   AC++;
		Bu1 = XtCreateManagedWidget ("bu", flatButtonsWidgetClass,
					     Form, args, AC);
	}
	else {
		AC = 0;
		XtSetArg(args[AC], XtNbuttonType, OL_OBLONG_BTN);  AC++;
		XtSetArg(args[AC], XtNclientData, Indicator);	   AC++;
		XtSetArg(args[AC], XtNitemFields, Save_Fields);    AC++;
		XtSetArg(args[AC], XtNnumItemFields, 2);           AC++;
		XtSetArg(args[AC], XtNitems, Save_Items);          AC++;
		XtSetArg(args[AC], XtNlayoutType, OL_FIXEDROWS);   AC++;
		XtSetArg(args[AC], XtNmeasure, 1);                 AC++;
		XtSetArg(args[AC], XtNnumItems, 1);                AC++;
		XtSetArg(args[AC], XtNyRefName, "cap6");           AC++;
		XtSetArg(args[AC], XtNyOffset, 25);	           AC++;
		XtSetArg(args[AC], XtNyAddHeight, TRUE);	   AC++;
		XtSetArg(args[AC], XtNxOffset, 50);	           AC++;
		Bu1 = XtCreateManagedWidget ("bu", flatButtonsWidgetClass,
					     Form, args, AC);
	}

	AC = 0;
        XtSetArg(args[AC], XtNbuttonType, OL_OBLONG_BTN);           AC++;
        XtSetArg(args[AC], XtNitemFields, Dis_Fields);              AC++;
        XtSetArg(args[AC], XtNnumItemFields, XtNumber(Dis_Fields)); AC++;
        XtSetArg(args[AC], XtNclientData, SettingsTop);             AC++;
        XtSetArg(args[AC], XtNitems, Dis_Items);                    AC++;
        XtSetArg(args[AC], XtNlayoutType, OL_FIXEDROWS);            AC++;
        XtSetArg(args[AC], XtNmeasure, 1);                          AC++;
        XtSetArg(args[AC], XtNnumItems, 1);                         AC++;
	XtSetArg(args[AC], XtNyRefWidget, Bu1);                     AC++;
	XtSetArg(args[AC], XtNyOffset, 0);	                    AC++;
	XtSetArg(args[AC], XtNxRefName, "form");                    AC++;
	XtSetArg(args[AC], XtNxAttachRight, TRUE);	            AC++;
	XtSetArg(args[AC], XtNxVaryOffset, TRUE);	            AC++;
	XtSetArg(args[AC], XtNxAttachOffset, 50);	            AC++;
        Bu2 = XtCreateManagedWidget ("bu", flatButtonsWidgetClass,
                                     Form, args, AC);

	AC = 0;
	XtSetArg(args[AC], XtNstring, "   ");    AC++;
	XtSetArg(args[AC], XtNyRefWidget, Bu2);  AC++;
	XtSetArg(args[AC], XtNyOffset, 0);       AC++;
	XtSetArg(args[AC], XtNyAddHeight, TRUE); AC++;
	Invis = XtCreateManagedWidget ("se", staticTextWidgetClass,
					Form, args, AC);

	XtRealizeWidget(SettingsTop);
} /* Settings */

void _Jump(Widget W, XtPointer ClientData, XtPointer CallData)
{
	XtCallAcceptFocus(ClientData, 0);
}

void Call_Dismiss(Widget W, Widget ClientData, XtPointer CallData)
{
	extern int Xtermid;
	extern Widget SystemsTop;
	extern Boolean Systems_Mapped;

	if(Systems_Mapped == True)
		XtSetSensitive(SystemsTop, True);

	XtDestroyWidget((Widget)ClientData);
        (void)Call_Enter(NULL, Xtermid, NULL, NULL);
} /* Call_Dismiss */

void Call_Save(Widget W, XtPointer ClientData, XtPointer CallData)
{
	Arg args[1];
	void Save_System_Entry();
	extern Widget Te2, SystemsTop;
	extern Dial_Info DialInfoBuf;
	extern OlListToken LastToken;

	XtSetArg(args[0], XtNstring, &DialInfoBuf.Line);
        XtGetValues(Te2, args, 1);

	XtSetArg(args[0], XtNstring, &DialInfoBuf.System);
        XtGetValues(Te1, args, 1);

	if((int)ClientData == MODIFY) {
		(void)Modify_Systems(LastToken, MODIFY);
        	(void)Set_Systems(NULL, (XtPointer)PERSONAL, NULL);
	}
	else
		(void)Save_System_Entry();
	(void)Call_Dismiss(NULL, SettingsTop, NULL);
} /* Call_Save */

void Call_Dial(Widget W, XtPointer ClientData, XtPointer CallData)
{
	extern Widget Stub;
	extern Dial_Info DialInfoBuf;
	extern int Modem_fd;

	if(Modem_fd != 0) {
		(void)DialerError(NONFATAL, ALREADYCONNECT);
		return;
	}

	XSync(XtDisplay(Stub), False),
	(void)Init_Dial(&DialInfoBuf, MANUAL);
	(void)Call_Dismiss(NULL, SettingsTop, NULL);
} /* Call_Dial */

void Set_Speed(Widget W, XtPointer ClientData, XtPointer CallData)
{
	extern Dial_Info DialInfoBuf;

	DialInfoBuf.Speed = 0;
	DialInfoBuf.Speed = (int)ClientData;
} /* Set_Speed */

void Set_Size(Widget W, XtPointer ClientData, XtPointer CallData)
{
	extern Dial_Info DialInfoBuf;

	DialInfoBuf.CharSize = 0;
	switch ((int)ClientData) {
		case 6:
			DialInfoBuf.CharSize = CS6;
			break;
		case 7:
			DialInfoBuf.CharSize = CS7;
			break;
		case 8:
			DialInfoBuf.CharSize = CS8;
			break;
	}
} /* Set_Size */

void Set_Parity(Widget W, XtPointer ClientData, XtPointer CallData)
{
	extern Dial_Info DialInfoBuf;

	DialInfoBuf.Parity = 0;
	if(strcmp(ClientData, "EVEN") == 0)
		DialInfoBuf.Parity = PARENB;
	if(strcmp(ClientData, "ODD") == 0)
		DialInfoBuf.Parity = (PARENB | PARODD);
} /* Set_Parity */

void Set_Flow(Widget W, XtPointer ClientData, XtPointer CallData)
{
	extern Dial_Info DialInfoBuf;

	DialInfoBuf.Flow = 0;
	if(strcmp(ClientData, "ON") == 0) {
		DialInfoBuf.Flow = (IXON | IXOFF);
	}
} /* Set_Flow */

void Save_System_Entry()
{
	FILE *fp, *fopen();
	extern Dial_Info DialInfoBuf;
	extern char Systems_File[];

	if((fp = fopen(Systems_File, APPEND)) == NULL) {
		(void)DialerError(NONFATAL, OPENFORSAVE, Systems_File);
		return;
	}

	(void)fprintf(fp, "%s;", DialInfoBuf.System);
	(void)fprintf(fp, "%s;", DialInfoBuf.Line);
	(void)fprintf(fp, "%d;", DialInfoBuf.Speed);
	switch (DialInfoBuf.CharSize) {
		case CS8: 
			(void)fprintf(fp, "%s;", "CS8");
			break;
		case CS7:
			(void)fprintf(fp, "%s;", "CS7");
			break;
		case CS6:
			(void)fprintf(fp, "%s;", "CS6");
			break;
		default:
			(void)fprintf(fp, "%s;", "CS8");
	}

	switch(DialInfoBuf.Parity) {
		case (PARENB|PARODD):
			(void)fprintf(fp, "%s;", "ODD");
			break;
		case (PARENB):
			(void)fprintf(fp, "%s;", "EVEN");
			break;
		default:
			(void)fprintf(fp, "%s;", "NONE");
	}

	switch(DialInfoBuf.Flow) {
		case (IXON|IXOFF):
			(void)fprintf(fp, "%s\n", "ON");
			break;
		default:
			(void)fprintf(fp, "%s\n", "OFF");
	}

	(void)fclose(fp);
	(void)Set_Systems(NULL, (XtPointer)PERSONAL, NULL);

} /* Save_System_Entry */

void Set_Settings_Screen(char *Buffer)
{
	struct sys LocalSys;
	Arg args[1];
	int SpeedIndex,
	    SizeIndex,
	    ParityIndex,
	    FlowIndex;
	extern Dial_Info DialInfoBuf;
	extern Widget Speed, Size, Parity, Flow;

	(void)strcpy(LocalSys.System,   strtok(Buffer, ";"));
        (void)strcpy(LocalSys.Phone,    strtok(NULL, ";"));
        (void)strcpy(LocalSys.Speed,    strtok(NULL, ";"));
        (void)strcpy(LocalSys.CharSize, strtok(NULL, ";"));
        (void)strcpy(LocalSys.Parity,   strtok(NULL, ";"));
        (void)strcpy(LocalSys.Flow,     strtok(NULL, ";"));

	XtSetArg(args[0], XtNstring, LocalSys.System);
	XtSetValues(Te1, args, 1);

	XtSetArg(args[0], XtNstring, LocalSys.Phone);
	XtSetValues(Te2, args, 1);

	if(strcmp(LocalSys.Speed, "38400") == 0) {
		DialInfoBuf.Speed = 38400;
		XtSetArg(args[0], XtNset, True);
		SpeedIndex = 6;
	}
	else if(strcmp(LocalSys.Speed, "19200") == 0) {
		DialInfoBuf.Speed = 19200;
		XtSetArg(args[0], XtNset, True);
		SpeedIndex = 5;
	}
	else if(strcmp(LocalSys.Speed, "9600") == 0) {
		DialInfoBuf.Speed = 9600;
		XtSetArg(args[0], XtNset, True);
		SpeedIndex = 4;
	}
	else if(strcmp(LocalSys.Speed, "4800") == 0) {
		DialInfoBuf.Speed = 4800;
		XtSetArg(args[0], XtNset, True);
		SpeedIndex = 3;
	}
	else if(strcmp(LocalSys.Speed, "2400") == 0) {
		DialInfoBuf.Speed = 2400;
		XtSetArg(args[0], XtNset, True);
		SpeedIndex = 2;
	}
	else if(strcmp(LocalSys.Speed, "1200") == 0) {
		DialInfoBuf.Speed = 1200;
		XtSetArg(args[0], XtNset, True);
		SpeedIndex = 1;
	}
	else if(strcmp(LocalSys.Speed, "300") == 0) {
		DialInfoBuf.Speed = 300;
		XtSetArg(args[0], XtNset, True);
		SpeedIndex = 0;
	}

	OlFlatSetValues(Speed, SpeedIndex, args, 1);

	if(strcmp(LocalSys.CharSize, "CS8") == 0) {
		DialInfoBuf.CharSize = CS8;
		XtSetArg(args[0], XtNset, True);
		SizeIndex = 2;
	}
	else if(strcmp(LocalSys.CharSize, "CS7") == 0) {
		DialInfoBuf.CharSize = CS7;
		XtSetArg(args[0], XtNset, True);
		SizeIndex = 1;
	}
	else if(strcmp(LocalSys.CharSize, "CS6") == 0) {
		DialInfoBuf.CharSize = CS6;
		XtSetArg(args[0], XtNset, True);
		SizeIndex = 0;
	}

	OlFlatSetValues(Size, SizeIndex, args, 1);

	if(strcmp(LocalSys.Parity, "NONE") == 0) {
		DialInfoBuf.Flow = 0;
		XtSetArg(args[0], XtNset, True);
		ParityIndex = 2;
	}
	else if(strcmp(LocalSys.Parity, "ODD") == 0) {
		DialInfoBuf.Flow = (PARENB | PARODD);
		XtSetArg(args[0], XtNset, True);
		ParityIndex = 1;
	}
	else if(strcmp(LocalSys.Parity, "EVEN") == 0) {
		DialInfoBuf.Flow = (PARENB);
		XtSetArg(args[0], XtNset, True);
		ParityIndex = 0;
	}

	OlFlatSetValues(Parity, ParityIndex, args, 1);

	if(strcmp(LocalSys.Flow, "ON") == 0) {
		DialInfoBuf.Flow = (IXON|IXOFF);
		XtSetArg(args[0], XtNset, True);
		FlowIndex = 0;
	}
	else if(strcmp(LocalSys.Flow, "OFF") == 0) {
		DialInfoBuf.Flow = 0;
		XtSetArg(args[0], XtNset, True);
		FlowIndex = 1;
	}

	OlFlatSetValues(Flow, FlowIndex, args, 1);

} /* Set_Settings_Screen */
